[proj] 01/05: Imported Upstream version 4.9.2~rc2+1

Sebastiaan Couwenberg sebastic at moszumanska.debian.org
Thu Sep 10 22:52:09 UTC 2015


This is an automated email from the git hooks/post-receive script.

sebastic pushed a commit to branch master
in repository proj.

commit 4a65909ae2bad40264a0ff6c8ec202485932c2b4
Author: Bas Couwenberg <sebastic at xs4all.nl>
Date:   Fri Sep 11 00:22:03 2015 +0200

    Imported Upstream version 4.9.2~rc2+1
---
 CMakeLists.txt       |  15 ++++++-
 ChangeLog            |   3 ++
 NEWS                 | 110 ++++++++++++++++++++++++++++-----------------------
 src/Makefile.am      |   2 +-
 src/Makefile.in      |   2 +-
 src/pj_param.c       |  16 ++++----
 src/proj_config.h.in |   3 ++
 src/projects.h       |   4 +-
 8 files changed, 93 insertions(+), 62 deletions(-)

diff --git a/CMakeLists.txt b/CMakeLists.txt
index 8bd0f26..a6c281a 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -33,7 +33,7 @@ colormsg(_HIBLUE_ "Configuring PROJ:")
 include(Proj4Version)
 proj_version(MAJOR 4 MINOR 9 PATCH 2)
 set(PROJ_API_VERSION "10")
-set(PROJ_BUILD_VERSION "10.0.1")
+set(PROJ_BUILD_VERSION "10.0.0")
 
 #################################################################################
 # Build features and variants
@@ -43,6 +43,19 @@ include(Proj4Config)
 include(Proj4Mac)
 include(policies)
 
+#################################################################################
+# threading configuration
+#################################################################################
+set(CMAKE_THREAD_PREFER_PTHREAD TRUE)
+find_package (Threads)
+
+include(CheckIncludeFiles)
+include(CheckSymbolExists)
+CHECK_SYMBOL_EXISTS(PTHREAD_MUTEX_RECURSIVE pthread.h HAVE_PTHREAD_MUTEX_RECURSIVE_DEFN)
+if (HAVE_PTHREAD_MUTEX_RECURSIVE_DEFN)
+    add_definitions(-DHAVE_PTHREAD_MUTEX_RECURSIVE=1)
+endif()
+
 boost_report_value(PROJ_PLATFORM_NAME)
 boost_report_value(PROJ_COMPILER_NAME)
 
diff --git a/ChangeLog b/ChangeLog
index a00c974..dfa6726 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,6 @@
+2015-09-10 sisyphus <https://github.com/sisyphus>
+	* : Rename PVALUE in pj_param.cto prevent Windows variable name clash
+
 2015-09-10 Bas Couwenberg <https://github.com/sebastic>
 	* : Don't include files in proj dist, also included in proj-datumgrids
 	dist #301
diff --git a/NEWS b/NEWS
index 985a07f..6dedc72 100644
--- a/NEWS
+++ b/NEWS
@@ -1,16 +1,28 @@
+4.9.2 Release Notes
+-------------------
+
+ o proj_def.dat was missing from source distribution
+   see https://github.com/OSGeo/proj.4/issues/274 for more detail
+
+ o Update Geodesic library from GeographicLib
+
+ o Remove setlocale() use in pj_init_ctx()
+
+ o Renamed PVALUE in pj_param.c to prevent clash with Windows
+
 4.9.1 Release Notes
 -------------------
- 
- o 4.9.0RC2 release was abandoned because it was not promoted in a 
-   timely fashion. Subsequent maintenance of tickets has continued, 
+
+ o 4.9.0RC2 release was abandoned because it was not promoted in a
+   timely fashion. Subsequent maintenance of tickets has continued,
    and a new 4.9.1 release was issued in its place.
 
  o Implement inverse solution for Winkel Tripel from Drazan Tutic #250
 
- o More CMake configuration tweaks. The CMake configuration is probably 
-   not at feature parity with the autotools builds at this point but it 
+ o More CMake configuration tweaks. The CMake configuration is probably
+   not at feature parity with the autotools builds at this point but it
    is converging #256
- 
+
  o Tweak initialization ordering around setlocal which may have caused
    issues #237
 
@@ -19,7 +31,7 @@
  o Fix NaN handling by geod_inverse and geod_polygon_addedge #251 & #253
 
  o Update config.sub and config.guess #257
- 
+
  o Adapt Charles Karney's CMake patches for smoother build #258
 
  o Define default PROJ_LIB location for CMake compilation #261
@@ -43,7 +55,7 @@
  o Implement new virtual file api (projFileAPI) so that all access to grid
    shift and init files can be hooked.
 
- o Replace geodesic implementation with one from Charles Karney and add a 
+ o Replace geodesic implementation with one from Charles Karney and add a
    supported public interface (geodesic.h).
 
  o Upgraded to EPSG 8.5.
@@ -68,12 +80,12 @@
  o Added HEALPIX, rHEALPIX and Icosahedral Snyder Equal Area projections.
 
  o nad2bin now produces "CTable2" format grid shift files by default which
-   are platform independent.  
+   are platform independent.
 
- o nad2nad removed, use cs2cs for datum shift operations. 
+ o nad2nad removed, use cs2cs for datum shift operations.
 
  o projects.h no longer installed as a public include file.  Please try to
-   only use proj_api.h. 
+   only use proj_api.h.
 
  o Add pj_get_spheroid_defn() accessor.
 
@@ -84,8 +96,8 @@
 
  o Upgrade to EPSG 7.9.  Some changes in ideal datum selection.
 
- o JNI bindings reworked, org.proj4.Projections deprecated in favor of 
-   org.proj4.PJ. 
+ o JNI bindings reworked, org.proj4.Projections deprecated in favor of
+   org.proj4.PJ.
 
  o Added preliminary vertical datum support.
 
@@ -97,13 +109,13 @@
  o +proj=omerc implementatioin replaced with code from libproj4.  +rot_conv
    flag no longer works, and some coordinate systems (ie. Malaysian) will
    need to use +gamma instead.  "epsg" init file updated accordingly.
-   
+
 
 4.7.0 Release Notes
 -------------------
 
  o Added in memory caching of init file search results for substantial
-   acceleration in some application environments (like MapServer). 
+   acceleration in some application environments (like MapServer).
 
  o Regenerated nad/epsg init file with EPSG 7.1 database, including new
    support for Google Mercator (EPSG:3857).
@@ -122,15 +134,15 @@
    if more than 90 degrees away from the central meridian (#5).  This change
    may only be temporary till a more comprehensive solution is found.
 
- o Fixed handling of extra text in cs2cs.  
+ o Fixed handling of extra text in cs2cs.
 
  o Renamed INSTALL to INSTALL.TXT.
- 
+
  o The eqc projection has been generalized to include a latitude of origin.
 
  o Added the glabsgm (Gauss Laborde / Sphere Geometric Mean) projection,
    and gstmerc variation.
- 
+
  o nad/IGNF init catalogue created.
 
  o added the ntf_r93.gsb datum shift file.
@@ -138,9 +150,9 @@
  o Add /Op in nmake.opt compile options to avoid VC7 optimization bug (#12)
 
  o Fix testvarious test script so it works properly when grid files available
- 
 
- 
+
+
 4.6.0 Release Notes
 -------------------
 
@@ -151,28 +163,28 @@
    ellipsoids getting changed to spheres for spherical projections.
 
  o Upgrade to EPSG 6.13
- 
+
  o Added "900913" "Google Mercator" code in nad/esri.extra.
 
- o Avoid some static variable based multi-threading problems. 
+ o Avoid some static variable based multi-threading problems.
 
  o Improve error recovery if ctable style datum shift grid fails to load.
 
  o Support drive letters properly in PROJ_LIB paths for win32.
- 
- o Fix occasional problem with DMS parsing. 
+
+ o Fix occasional problem with DMS parsing.
 
  o Removed non-functional mpoly projection.
 
- o add lonlat, and latlon as aliases for longlat. 
+ o add lonlat, and latlon as aliases for longlat.
+
 
-   
 4.5.0 Release Notes
 -------------------
 
- o Microsoft Visual Studio 8 compatibility changes. 
- 
- o Upgraded to EPSG 6.11.1 database. 
+ o Microsoft Visual Studio 8 compatibility changes.
+
+ o Upgraded to EPSG 6.11.1 database.
 
  o Several bug fixes to pj_transform() to handle transient errors properly.
 
@@ -187,15 +199,15 @@
 4.4.9 Release Notes
 -------------------
 
- o Win32 build uses proj.dll by default now. 
+ o Win32 build uses proj.dll by default now.
 
  o Added accessor functions for the datums, ellps, prime_meridians, units and
-   main projection definition lists so they can be used on windows where 
+   main projection definition lists so they can be used on windows where
    data objects exported from the DLL don't work easily.
 
- o Added JNI (Java Native Interface) support within the jniwrap directory, 
+ o Added JNI (Java Native Interface) support within the jniwrap directory,
    and some supporting entry points directly in the proj dll/so.   See
-   --with-jni configure switch, and jniwrap/README. 
+   --with-jni configure switch, and jniwrap/README.
 
  o Added the proj=stereoa and proj=geos projections, incorporated from
    Gerald's libproj4.
@@ -208,38 +220,38 @@
 
  o Updated epsg file to EPSG 6.5, added other.extra pseudo-EPSG WMS definitions
 
- o Made significant fixes to prime meridian support. 
- 
+ o Made significant fixes to prime meridian support.
+
  o Substantially change pj_datum_transform(), so it and pj_transform() will
    work between coordinate systems with different ellipsoids but no datum
-   shift information (assume +towgs84=0,0,0). 
+   shift information (assume +towgs84=0,0,0).
 
  o Added pj_get_release() function.
 
- o Ensure pj_transform() will try to transform all points in provided list if 
-   even some might transform properly.  
+ o Ensure pj_transform() will try to transform all points in provided list if
+   even some might transform properly.
 
  o Improved the accuracy of Geocentric_To_Geodetic() via an iterative
-   solution.  
+   solution.
 
- o Various other bug fixes. 
+ o Various other bug fixes.
 
 
 4.4.7 Release Notes
 -------------------
 
- o Added NTv2 (.gsb) grid shift file support.  
+ o Added NTv2 (.gsb) grid shift file support.
 
  o Modified datum shift support so that data file data is only loaded if
-   needed.  Also added 'null' grid as a fallback option, and support for 
-   making grids optional (prefix with '@' in +nadgrids). 
+   needed.  Also added 'null' grid as a fallback option, and support for
+   making grids optional (prefix with '@' in +nadgrids).
 
- o Regenerated nad/epsg file with towgs84 parameters for non-greenwich prime 
+ o Regenerated nad/epsg file with towgs84 parameters for non-greenwich prime
    meridians.
 
  o Updated nad/esri file with better generated form from Paul Ramsey.
 
- o Various bug fixes. 
+ o Various bug fixes.
 
 
 4.4.6 Release Notes
@@ -249,17 +261,17 @@
    Gerald.
 
  o Updated 'espg' translation file for EPSG 6.2.2 with better support for
-   prime meridians. 
+   prime meridians.
 
  o Added Prime Meridians via +pm command switch to cs2cs (and pj_transform).
 
- o Fixed bug with 7 parameter transforms. 
+ o Fixed bug with 7 parameter transforms.
 
- o Added 'esri' pseudo-epsg coordinate system file. 
+ o Added 'esri' pseudo-epsg coordinate system file.
 
  o Cleanup so that PROJ.4 compiles clean as C++ code.
 
  o Added pj_get_def() to expand definitions of stuff like +init clauses.
 
  o Added a Krovak implementation (proj=krov).  Note this may change again
-   in the next release. 
+   in the next release.
diff --git a/src/Makefile.am b/src/Makefile.am
index 3344a7e..6f8bc0a 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -29,7 +29,7 @@ test228_LDADD = libproj.la @THREAD_LIB@
 
 lib_LTLIBRARIES = libproj.la
 
-libproj_la_LDFLAGS = -no-undefined -version-info 10:0:1
+libproj_la_LDFLAGS = -no-undefined -version-info 10:0:0
 
 libproj_la_SOURCES = \
 	pj_list.h \
diff --git a/src/Makefile.in b/src/Makefile.in
index fbc3b76..d455c59 100644
--- a/src/Makefile.in
+++ b/src/Makefile.in
@@ -402,7 +402,7 @@ geod_LDADD = libproj.la
 multistresstest_LDADD = libproj.la @THREAD_LIB@
 test228_LDADD = libproj.la @THREAD_LIB@
 lib_LTLIBRARIES = libproj.la
-libproj_la_LDFLAGS = -no-undefined -version-info 10:0:1
+libproj_la_LDFLAGS = -no-undefined -version-info 10:0:0
 libproj_la_SOURCES = \
 	pj_list.h \
 	PJ_aeqd.c PJ_gnom.c PJ_laea.c PJ_mod_ster.c \
diff --git a/src/proj_config.h.in b/src/proj_config.h.in
index 7a8d694..9e3c731 100644
--- a/src/proj_config.h.in
+++ b/src/proj_config.h.in
@@ -21,6 +21,9 @@
 /* Define to 1 if you have the <memory.h> header file. */
 #undef HAVE_MEMORY_H
 
+/* Define if your pthreads implementation have PTHREAD_MUTEX_RECURSIVE */
+#undef HAVE_PTHREAD_MUTEX_RECURSIVE
+
 /* Define to 1 if you have the <stdint.h> header file. */
 #undef HAVE_STDINT_H
 
diff --git a/src/projects.h b/src/projects.h
index ac95f69..fe6a44c 100644
--- a/src/projects.h
+++ b/src/projects.h
@@ -156,7 +156,7 @@ typedef struct { double x, y; }     XY;
 typedef struct { double lam, phi; } LP;
 #endif
 
-typedef union { double  f; int  i; char *s; } PVALUE;
+typedef union { double  f; int  i; char *s; } PROJVALUE;
 struct PJconsts;
     
 struct PJ_LIST {
@@ -395,7 +395,7 @@ void set_rtodms(int, int);
 char *rtodms(char *, double, int, int);
 double adjlon(double);
 double aacos(projCtx,double), aasin(projCtx,double), asqrt(double), aatan2(double, double);
-PVALUE pj_param(projCtx ctx, paralist *, const char *);
+PROJVALUE pj_param(projCtx ctx, paralist *, const char *);
 paralist *pj_mkparam(char *);
 int pj_ell_set(projCtx ctx, paralist *, double *, double *);
 int pj_datum_set(projCtx,paralist *, PJ *);

diff --git a/src/pj_param.c b/src/pj_param.c
index ed6ce27..434d453 100644
--- a/src/pj_param.c
+++ b/src/pj_param.c
@@ -23,22 +23,22 @@ pj_mkparam(char *str) {
 /*      character in `opt' is a parameter type which can take the       */
 /*      values:                                                         */
 /*                                                                      */
 /*       `t' - test for presence, return TRUE/FALSE in PVALUE.i         */
 /*       `i' - integer value returned in PVALUE.i                       */
 /*       `d' - simple valued real input returned in PVALUE.f            */
 /*       `r' - degrees (DMS translation applied), returned as           */
 /*             radians in PVALUE.f                                      */
 /*       `s' - string returned in PVALUE.s                              */
 /*       `b' - test for t/T/f/F, return in PVALUE.i                     */
 /*                                                                      */
 /************************************************************************/
 
-	PVALUE /* test for presence or get parameter value */
+	PROJVALUE /* test for presence or get parameter value */
 pj_param(projCtx ctx, paralist *pl, const char *opt) {
 
 	int type;
 	unsigned l;
-	PVALUE value;
+	PROJVALUE value;
 
 	if( ctx == NULL )
 		ctx = pj_get_default_ctx();
@@ -23,22 +23,22 @@ pj_mkparam(char *str) {
 /*      values:                                                         */
 /*                                                                      */
-/*       `t' - test for presence, return TRUE/FALSE in PVALUE.i         */
-/*       `i' - integer value returned in PVALUE.i                       */
-/*       `d' - simple valued real input returned in PVALUE.f            */
+/*       `t' - test for presence, return TRUE/FALSE in PROJVALUE.i         */
+/*       `i' - integer value returned in PROJVALUE.i                       */
+/*       `d' - simple valued real input returned in PROJVALUE.f            */
 /*       `r' - degrees (DMS translation applied), returned as           */
@@ -23,22 +23,22 @@ pj_mkparam(char *str) {
 /*       `r' - degrees (DMS translation applied), returned as           */
-/*             radians in PVALUE.f                                      */
-/*       `s' - string returned in PVALUE.s                              */
-/*       `b' - test for t/T/f/F, return in PVALUE.i                     */
+/*             radians in PROJVALUE.f                                      */
+/*       `s' - string returned in PROJVALUE.s                              */
+/*       `b' - test for t/T/f/F, return in PROJVALUE.i                     */
 /*                                                                      */
 /************************************************************************/
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-grass/proj.git



More information about the Pkg-grass-devel mailing list